@@ -17,14 +17,12 @@
 # You should have received a copy of the GNU General Public License
 # along with Rose. If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
-"""rose stem [path]
-
-Install a rose-stem suite using cylc install.
-
-To run a rose-stem suite use "cylc play".
+"""rose stem [options] [path]
 
 Install a suitable suite with a specified set of source tree(s).
 
+To run a rose-stem suite use "cylc play".
+
 Default values of some of these settings are suite-dependent, specified
 in the `rose-suite.conf` file.
 
@@ -153,7 +151,9 @@ class RoseStemVersionException(Exception):
     def __init__(self, version):
         Exception.__init__(self, version)
         if version is None:
-            self.suite_version = "not rose-stem compatible"
+            self.suite_version = (
+                "does not have ROSE_VERSION set in the rose-suite.conf"
+            )
         else:
             self.suite_version = "at version %s" % (version)
 
@@ -225,24 +225,32 @@ class StemRunner:
 
     def __init__(self, opts, reporter=None, popen=None, fs_util=None):
         self.opts = opts
+
         if reporter is None:
             self.reporter = Reporter(opts.verbosity - opts.quietness)
         else:
             self.reporter = reporter
+
         if popen is None:
             self.popen = RosePopener(event_handler=self.reporter)
         else:
             self.popen = popen
+
         if fs_util is None:
             self.fs_util = FileSystemUtil(event_handler=self.reporter)
         else:
             self.fs_util = fs_util
+
         self.host_selector = HostSelector(event_handler=self.reporter,
                                           popen=self.popen)
 
     def _add_define_option(self, var, val):
-        """Add a define option passed to the SuiteRunner."""
+        """Add a define option passed to the SuiteRunner.
 
+        Args:
+            var: Name of variable to set
+            val: Value of variable to set
+        """
         if self.opts.defines:
             self.opts.defines.append(SUITE_RC_PREFIX + var + '=' + val)
         else:
@@ -250,7 +258,7 @@ class StemRunner:
         self.reporter(ConfigVariableSetEvent(var, val))
         return
 
-    def _get_base_dir(self, item):
+    def _get_fcm_loc_layout_info(self, src_tree):
         """Given a source tree return the following from 'fcm loc-layout':
            * url
            * sub_tree
@@ -259,15 +267,17 @@ class StemRunner:
            * project
         """
 
-        ret_code, output, stderr = self.popen.run('fcm', 'loc-layout', item)
+        ret_code, output, stderr = self.popen.run(
+            'fcm', 'loc-layout', src_tree)
         if ret_code != 0:
-            raise ProjectNotFoundException(item, stderr)
+            raise ProjectNotFoundException(src_tree, stderr)
 
         ret = {}
         for line in output.splitlines():
             if ":" not in line:
                 continue
             key, value = line.split(":", 1)
+
             if key and value:
                 ret[key] = value.strip()
 
@@ -289,7 +299,8 @@ class StemRunner:
                     break
         return project
 
-    def _deduce_mirror(self, source_dict, project):
+    @staticmethod
+    def _deduce_mirror(source_dict, project):
         """Deduce the mirror location of this source tree."""
 
         # Root location for project
@@ -331,7 +342,7 @@ class StemRunner:
             print(f"[WARN] Forcing project for '{item}' to be '{project}'")
             return project, item, item, '', ''
 
-        source_dict = self._get_base_dir(item)
+        source_dict = self._get_fcm_loc_layout_info(item)
         project = self._get_project_from_url(source_dict)
         if not project:
             raise ProjectNotFoundException(item)
@@ -365,10 +376,11 @@ class StemRunner:
         try:
             basedir = self._ascertain_project(os.getcwd())[1]
         except ProjectNotFoundException:
-            if self.opts.source:
-                basedir = os.path.abspath(self.opts.source)
+            if self.opts.workflow_conf_dir:
+                basedir = os.path.abspath(self.opts.workflow_conf_dir)
             else:
-                basedir = os.getcwd()
+                basedir = os.path.abspath(os.getcwd())
+
         name = os.path.basename(basedir)
         self.reporter(NameSetEvent(name))
         return name
@@ -382,12 +394,17 @@ class StemRunner:
             basedir = self.opts.stem_sources[0]
         else:
             basedir = self._ascertain_project(os.getcwd())[1]
+
         suitedir = os.path.join(basedir, DEFAULT_TEST_DIR)
         suitefile = os.path.join(suitedir, "rose-suite.conf")
+
         if not os.path.isfile(suitefile):
             raise RoseSuiteConfNotFoundException(suitedir)
+
         self.opts.suite = suitedir
+
         self._check_suite_version(suitefile)
+
         return suitedir
 
     def _read_auto_opts(self):
@@ -480,10 +497,10 @@ class StemRunner:
                         elements[0], '"' + elements[1] + '"')
 
         # Change into the suite directory
-        if getattr(self.opts, 'source', None):
-            self.reporter(SuiteSelectionEvent(self.opts.source))
+        if getattr(self.opts, 'workflow_conf_dir', None):
+            self.reporter(SuiteSelectionEvent(self.opts.workflow_conf_dir))
             self._check_suite_version(
-                os.path.join(self.opts.source, 'rose-suite.conf'))
+                os.path.join(self.opts.workflow_conf_dir, 'rose-suite.conf'))
         else:
             thissuite = self._this_suite()
             self.fs_util.chdir(thissuite)
@@ -497,7 +514,8 @@ class StemRunner:
 
 
 def get_source_opt_from_args(opts, args):
-    """Convert sourcedir given as arg or implied by no arg to opts.source.
+    """Convert sourcedir given as arg or implied by no arg to
+    opts.workflow_conf_dir.
 
     Possible outcomes:
         No args given:
@@ -512,19 +530,19 @@ def get_source_opt_from_args(opts, args):
     """
     if len(args) == 0:
         # sourcedir not given:
-        opts.source = None
+        opts.workflow_conf_dir = None
         return opts
     elif os.path.isabs(args[-1]):
         # sourcedir given, and is abspath:
-        opts.source = args[-1]
+        opts.workflow_conf_dir = args[-1]
     else:
         # sourcedir given and is not abspath
-        opts.source = str(Path.cwd() / args[-1])
+        opts.workflow_conf_dir = str(Path.cwd() / args[-1])
 
     return opts
 
 
-def main():
+def _get_rose_stem_opts():
     """Implement rose stem."""
     # use the cylc install option parser
     parser = get_option_parser()
@@ -537,8 +555,8 @@ def main():
         "--task", "--group", "-t", "-g",
         help=(
             "Specify a group name to run. Additional groups can be specified"
-            "with further `--group` arguments. The suite will then convert the"
-            "groups into a series of tasks to run."
+            " with further `--group` arguments. The suite will then convert"
+            " the groups into a series of tasks to run."
         ),
         action="append",
         metavar="PATH/TO/FLOW",
@@ -548,14 +566,13 @@ def main():
         "--source", '-s',
         help=(
             "Specify a source tree to include in a rose-stem suite. The first"
-            "source tree must be a working copy as the location of the suite"
-            "and fcm-make config files are taken from it. Further source"
-            "trees can be added with additional `--source` arguments. "
-            "The project which is associated with a given source is normally "
-            "automatically determined using FCM, however the project can "
-            "be specified by putting the project name as the first part of "
-            "this argument separated by an equals sign as in the third "
-            "example above. Defaults to `.` if not specified."
+            " source tree must be a working copy, as the location of the suite"
+            " and fcm-make config files are taken from it. Further source"
+            " trees can be added with additional `--source` arguments."
+            " The project which is associated with a given source is normally"
+            " automatically determined using FCM, however the project can"
+            " be specified as '<project-name>=<project-path>'."
+            " Defaults to `.` if not specified."
         ),
         action="append",
         metavar="PATH/TO/FLOW",
@@ -565,7 +582,6 @@ def main():
     parser.add_option_group(rose_stem_options)
 
     parser.usage = __doc__
-
     opts, args = parser.parse_args(sys.argv[1:])
     # sliced sys.argv to drop 'rose-stem'
     opts = get_source_opt_from_args(opts, args)
@@ -574,16 +590,21 @@ def main():
     # verbosity as part of the parser, but rose needs opts.quietness too, so
     # hard set it.
     opts.quietness = 0
+    return parser, opts
 
+
+def main():
+    parser, opts = _get_rose_stem_opts()
+    rose_stem(parser, opts)
+
+
+def rose_stem(parser, opts):
     try:
         # modify the CLI options to add whatever rose stem would like to add
         opts = StemRunner(opts).process()
 
         # call cylc install
-        if hasattr(opts, 'source'):
-            cylc_install(parser, opts, opts.source)
-        else:
-            cylc_install(parser, opts)
+        cylc_install(opts, opts.workflow_conf_dir)
 
     except CylcError as exc:
         if opts.verbosity > 1:
@@ -595,7 +616,3 @@ def main():
             ),
             file=sys.stderr
         )
-
-
-if __name__ == "__main__":
-    main()
